/**
 * CITIZEN Android Label Print SDK
 * Copyright(C) 2016-2017 CITIZEN SYSTEMS JAPAN CO., LTD. All Rights Reserved.
 */
package com.citizen.sdk.labelprint;

import com.citizen.csjlabellib.LibBase.LibDesign;

import android.graphics.Typeface;

/**
 * Label design control class
 * @version 1.02
 */
public class LabelDesign extends LibDesign {

	public LabelDesign() {
	}

	/**
	 * Draws characters by using a printer device font.
	 * @param data : String data
	 * @param locale : Locale
	 * @param font : Font typeface
	 * @param rotation : Direction of rotation
	 * @param hexp : Horizontal magnification
	 * @param vexp : Vertical magnification
	 * @param size : Font size
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawTextPtrFont(String data, int locale, int font, int rotation, int hexp, int vexp, int size, int x, int y)
    {
		return super.drawTextPtrFont(data, locale, font, rotation, hexp, vexp, size, x, y);
    }

	/**
	 * Draws characters by using a downloaded font.
	 * @param data : String data
	 * @param encoding : Character encoding
	 * @param fontID : Font ID stored in the printer
	 * @param rotation : Direction of rotation
	 * @param hexp : Horizontal magnification
	 * @param vexp : Vertical magnification
	 * @param point : Font size
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawTextDLFont(String data, int encoding, String fontID, int rotation, int hexp, int vexp, int point, int x, int y)
    {
		return super.drawTextDLFont(data, encoding, fontID, rotation, hexp, vexp, point, x, y);
    }

	/**
	 * Draws characters by using a font installed in the terminal.
	 * @param data : String data
	 * @param fontType : Font name
	 * @param rotation : Direction of rotation
	 * @param hexp : Horizontal magnification
	 * @param vexp : Vertical magnification
	 * @param point : Font size
	 * @param style : Font style
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawTextLocalFont(String data, Typeface fontType, int rotation, int hRatio, int vRatio, int point, int style, int x, int y)
    {
		return super.drawTextLocalFont(data, fontType, rotation, hRatio, vRatio, point, style, x, y);
    }

	/**
	 * Draws characters by using a font installed in the terminal.
	 * @param data : String data
	 * @param fontType : Font name
	 * @param rotation : Direction of rotation
	 * @param hexp : Horizontal magnification
	 * @param vexp : Vertical magnification
	 * @param point : Font size
	 * @param style : Font style
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @param resolution : Resolution [dpi]
	 * @return Return value
	 */
    public int drawTextLocalFont(String data, Typeface fontType, int rotation, int hRatio, int vRatio, int point, int style, int x, int y, int resolution)
    {
		return super.drawTextLocalFont(data, fontType, rotation, hRatio, vRatio, point, style, x, y, resolution);
    }

	/**
	 * Draws characters by using a font installed in the terminal.
	 * @param data : String data
	 * @param fontType : Font name
	 * @param rotation : Direction of rotation
	 * @param hexp : Horizontal magnification
	 * @param vexp : Vertical magnification
	 * @param point : Font size
	 * @param style : Font style
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @param resolution : Resolution [dpi]
	 * @param measurementUnit : Measurement unit
	 * @return Return value
	 */
    public int drawTextLocalFont(String data, Typeface fontType, int rotation, int hRatio, int vRatio, int point, int style, int x, int y, int resolution, int measurementUnit)
    {
		return super.drawTextLocalFont(data, fontType, rotation, hRatio, vRatio, point, style, x, y, resolution, measurementUnit);
    }

	/**
	 * Draws a 1D (one-dimensional) barcode.
	 * @param data : String data
	 * @param symbology : Barcode type
	 * @param rotation : Direction of rotation
	 * @param thick : Thick bar width
	 * @param narrow : Narrow bar width
	 * @param height : Height of barcode
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @param showText : Human readable text
	 * @return Return value
	 */
    public int drawBarCode(String data, int symbology, int rotation, int thick, int narrow, int height, int x, int y, int showText)
    {
		return super.drawBarCode(data, symbology, rotation, thick, narrow, height, x, y, showText);
    }

	/**
	 * Draws the UPS MaxiCode barcode.
	 * @param data : String data
	 * @param rotation : Direction of rotation
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawMaxiCode(String[] data, int rotation, int x, int y)
    {
		return super.drawMaxiCode(data, rotation, x, y);
    }

	/**
	 * Draws the PDF417 barcode.
	 * @param data : String data
	 * @param encoding : Character encoding
	 * @param rotation : Direction of rotation
	 * @param exp : Magnification
	 * @param ECLevel : Error correction level
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawPDF417(String data, int encoding, int rotation, int exp, int ECLevel, int x, int y)
    {
		return super.drawPDF417(data, encoding, rotation, exp, ECLevel, x, y);
    }

	/**
	 * Draws the DataMatrix barcode.
	 * @param data : String data
	 * @param encoding : Character encoding
	 * @param rotation : Direction of rotation
	 * @param exp : Magnification
	 * @param ECLevel: Error correction level
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawDataMatrix(String data, int encoding, int rotation, int exp, int ECLevel, int x, int y)
    {
		return super.drawDataMatrix(data, encoding, rotation, exp, ECLevel, x, y);
    }

	/**
	 * Draws the QR code.
	 * @param data : String data
	 * @param encoding : Character encoding
	 * @param rotation : Direction of rotation
	 * @param exp : Magnification
	 * @param ECLevel: Error correction level
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawQRCode(String data, int encoding, int rotation, int exp, int ECLevel, int x, int y)
    {
		return super.drawQRCode(data, encoding, rotation, exp, ECLevel, x, y);
    }

	/**
	 * Draws the Aztec barcode.
	 * @param data : String data
	 * @param encoding : Character encoding
	 * @param rotation : Direction of rotation
	 * @param exp : Magnification
	 * @param ECLevel: Error correction level
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawAztec(String data, int encoding, int rotation, int exp, int ECLevel, int x, int y)
    {
		return super.drawAztec(data, encoding, rotation, exp, ECLevel, x, y);
    }

	/**
	 * Draws the GS1DataBar barcode.
	 * @param data : String data
	 * @param type : Barcode type
	 * @param rotation : Direction of rotation
	 * @param exp : Magnification
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawGS1DataBar(String[] data, int type, int rotation, int exp, int x, int y)
    {
		return super.drawGS1DataBar(data, type, rotation, exp, x, y);
    }

	/**
	 * Draws a graphic by using a graphic image stored in the printer.
	 * @param name : Graphic file name
	 * @param hexp : Horizontal magnification
	 * @param vexp : Vertical magnification
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawNVBitmap(String name, int hexp, int vexp, int x, int y)
    {
		return super.drawNVBitmap(name, hexp, vexp, x, y);
    }

	/**
	 * Draws a graphic image stored in the local computer.
	 * @param filePath Path to a local graphic file
	 * @param rotation : Direction of rotation
	 * @param width : Drawing width
	 * @param height : Drawing height
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @return Return value
	 */
    public int drawBitmap(String filePath, int rotation, int width, int height, int x, int y)
    {
		return super.drawBitmap(filePath, rotation, width, height, x, y);
    }

	/**
	 * Draws a graphic image stored in the local computer.
	 * @param filePath Path to a local graphic file
	 * @param rotation : Direction of rotation
	 * @param width : Drawing width
	 * @param height : Drawing height
	 * @param x : X-coordinate
	 * @param y : Y-coordinate
	 * @param resolution : Resolution [dpi]
	 * @param measurementUnit : Measurement unit
	 * @return Return value
	 */
    public int drawBitmap(String filePath, int rotation, int width, int height, int x, int y, int resolution, int measurementUnit)
    {
		return super.drawBitmap(filePath, rotation, width, height, x, y, resolution, measurementUnit);
    }

	/**
	 * Draws a line.
	 * @param x1 : Start position (X-coordinate)
	 * @param y1 : Start position (Y-coordinate)
	 * @param x2 : End position (X-coordinate)
	 * @param y2 : End position (Y-coordinate)
	 * @param thickness : Line width
	 * @return Return value
	 */
    public int drawLine(int x1, int y1, int x2, int y2, int thickness)
    {
		return super.drawLine(x1, y1, x2, y2, thickness);
    }

	/**
	 * Draws a box.
	 * @param x : Start position (X-coordinate)
	 * @param y : Start position (Y-coordinate)
	 * @param width : Box width
	 * @param height : Box height
	 * @param tickness : Line width
	 * @return Return value
	 */
    public int drawRect(int x, int y, int width, int height, int thickness)
    {
		return super.drawRect(x, y, width, height, thickness);
    }

	/**
	 * Draws a box of the shaded pattern.
	 * @param x : Start position (X-coordinate)
	 * @param y : Start position (Y-coordinate)
	 * @param width : Box width
	 * @param height : Box height
	 * @param pattern : Shaded pattern
	 * @return Return value
	 */
    public int fillRect(int x, int y, int width, int height, int pattern)
    {
		return super.fillRect(x, y, width, height, pattern);
    }

	/**
	 * Draws a circle.
	 * @param x : Start position (X-coordinate, center)
	 * @param y : Start position (Y-coordinate, center)
	 * @param radius : Radius
	 * @return Return value
	 */
    public int drawCircle(int x, int y, int radius)
    {
		return super.drawCircle(x, y, radius);
    }

	/**
	 * Draws a circle of the shaded pattern.
	 * @param x : Start position (X-coordinate, center)
	 * @param y : Start position (Y-coordinate, center)
	 * @param radius : Radius
	 * @param pattern : Shaded pattern
	 * @return Return value
	 */
    public int fillCircle(int x, int y, int radius, int pattern)
    {
		return super.fillCircle(x, y, radius, pattern);
    }

	/**
	 * Draws a closed polygon defined by arrays of x and y coordinates.
	 * @param x : X points
	 * @param y : Y points
	 * @return Return value
	 */
    public int drawPolygon(int[] x, int[] y)
    {
		return super.drawPolygon(x, y);
    }

	/**
	 * Draws a closed polygon defined by arrays of x and y coordinates, with the shaded pattern.
	 * @param x : X points
	 * @param y : Y points
	 * @param pattern : Shaded pattern
	 * @return Return value
	 */
    public int fillPolygon(int[] x, int[] y, int pattern)
    {
		return super.fillPolygon(x, y, pattern);
    }

	/**
	 * Embeds raw printer commands to the label design.
	 * @param data : Design command
	 * @return Return value
	 */
    public int embedRawDesignCommand(byte[] data)
    {
		return super.embedRawDesignCommand(data);
    }
}
